#
# kubernetes kube-controller-manager config
#

KUBE_CONTROLLER_MANAGER_ADDRESS="--address=0.0.0.0"
KUBE_CONTROLLER_MANAGER_KUBECONFIG="--kubeconfig=/etc/kubernetes/kubeconfig/kube-controller-manager.kubeconfig"
KUBE_CONTROLLER_MANAGER_LEADER_ELECT="--leader-elect=true"
KUBE_CONTROLLER_MANAGER_SERVICE_KEY="--service-account-private-key-file=/etc/kubernetes/certs/kube_apiserver.key"
KUBE_CONTROLLER_MANAGER_ROOT_CA="--root-ca-file=/etc/kubernetes/certs/k8sdc-ca.crt"
KUBE_CONTROLLER_MANAGER_ARGS=""
