#
# kubernetes kubelet config
#

KUBELET_ADDRESS="--address={{ main_ip }}"
KUBELET_HOSTNAME="--hostname_override={{ ansible_fqdn }}"
KUBELET_API_SERVER="--api_servers=https://{{ api_server_ip }}:{{ kubernetes_api_port }}"
KUBELET_DNS_IP="--cluster-dns={{ solutions.cs1_cluster_services.cluster_ip }}"
KUBELET_DNS_DOMAIN="--cluster-domain={{ solutions.cs1_cluster_services.domain }}"
KUBELET_KUBECONFIG="--kubeconfig=/etc/kubernetes/kubeconfig/kubelet.kubeconfig"
KUBELET_ARGS=""
